==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/hu.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
    "Storage invalid" : "A tároló érvénytelen",
    "Unknown error" : "Ismeretlen hiba",
    "All files" : "Az összes fájl",
    "Recent" : "Legutóbbi",
    "Favorites" : "Kedvencek",
    "File could not be found" : "Fájl nem található",
    "Move or copy" : "Mozgatás vagy másolás",
    "Download" : "Letöltés",
    "Delete" : "Törlés",
    "Home" : "Saját mappa",
    "Close" : "Bezárás",
    "Could not create folder \"{dir}\"" : "{dir} mappa nem hozható létre",
    "Upload cancelled." : "A feltöltést megszakítottuk.",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "A(z) {filename} fájl nem tölthető fel, mert ez vagy egy könyvtár, vagy pedig 0 bájtból áll.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nincs elég szabad hely. A feltöltés mérete {size1}, de csak ennyi hely van: {size2}.",
    "Target folder \"{dir}\" does not exist any more" : "A cél mappa már nem létezik: \"{dir}\"",
    "Not enough free space" : "Nincs elég szabad hely",
    "Uploading …" : "Feltöltés...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "A célmappa már nem létezik",
    "Error when assembling chunks, status code {status}" : "Hiba a darabok összerakásakor, Állapotkód {status}",
    "Actions" : "Műveletek",
    "Rename" : "Átnevezés",
    "Copy" : "Másol",
    "Disconnect storage" : "Tároló leválasztása",
    "Unshare" : "A megosztás visszavonása",
    "Could not load info for file \"{file}\"" : "Nem sikerült betölteni az információs fájl ehhez: \"{file}\"",
    "Files" : "Fájlok",
    "Details" : "Részletek",
    "Select" : "Kiválaszt",
    "Pending" : "Folyamatban",
    "Unable to determine date" : "Nem lehet meghatározni a dátumot",
    "This operation is forbidden" : "Tiltott művelet",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ez a könyvtár nem elérhető, kérem nézze meg a naplófájlokat vagy keresse az adminisztrátort",
    "Could not move \"{file}\", target exists" : "{file} fájl nem áthelyezhető, mert a cél már létezik",
    "Could not move \"{file}\"" : "{file} fájl nem áthelyezhető",
    "Could not copy \"{file}\", target exists" : "Nem sikerült \"{file}\" másolása, a cél már létezik",
    "Could not copy \"{file}\"" : "\"{file}\" másolása sikertelen",
    "Copied {origin} inside {destination}" : "{origin} átmásolva ide: {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} és {nbfiles} egyéb fájl átmásolva ide: {destination}",
    "{newName} already exists" : "{newName} már létezik",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nem átnevezhető erre: {fileName}, mert már nem létezik",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "{targetName} már használatban van ebben a mappában: {dir}. Kérjük, válassz másik nevet.",
    "Could not rename \"{fileName}\"" : "{fileName} fájl nem átnevezhető",
    "Could not create file \"{file}\"" : "{file} fájl nem létrehozható",
    "Could not create file \"{file}\" because it already exists" : "{file} fájl nem létrehozható, mert már létezik",
    "Could not create folder \"{dir}\" because it already exists" : "{dir} mappa nem hozható létre, mert már létezik",
    "Error deleting file \"{fileName}\"." : "Hiba történt {fileName} fájl törlése közben.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ehhez nincsenek keresési eredmények más mappákban: {tag}{filter}{endtag}",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "_%n folder_::_%n folders_" : ["%n mappa","%n mappa"],
    "_%n file_::_%n files_" : ["%n fájl","%n fájl"],
    "{dirs} and {files}" : "{dirs} és {files}",
    "_including %n hidden_::_including %n hidden_" : ["beleértve %n rejtett","beleértve %n rejtett"],
    "You don’t have permission to upload or create files here" : "Nincs jogosultságod fájlok feltöltéséhez vagy létrehozásához ide",
    "_Uploading %n file_::_Uploading %n files_" : ["%n fájl feltöltése","%n fájl feltöltése"],
    "New" : "Új",
    "{used} of {quota} used" : "{used} / {quota} felhasználva",
    "{used} used" : "{used} felhasználva",
    "\"{name}\" is an invalid file name." : "\"{name}\" érvénytelen, mint fájlnév.",
    "File name cannot be empty." : "A fájlnév nem lehet semmi.",
    "\"/\" is not allowed inside a file name." : "„/” nem szerepelhet fájlnévben.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nem engedélyetett fájltípus",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "A {owner} felhasználó tárolója betelt, a fájlok nem frissíthetők és szinkronizálhatók többet!",
    "Your storage is full, files can not be updated or synced anymore!" : "A tároló tele van, a fájlok nem frissíthetőek vagy szinkronizálhatóak a jövőben.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "A {owner} felhasználó tárolója majdnem betelt ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "A tároló majdnem tele van ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["egyezés '{filter}'","egyezés '{filter}'"],
    "View in folder" : "Megtekintés mappában",
    "Copied!" : "Másolva!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Közvetlen hivatkozás másolása (csak azoknál a felhasználóknál működik akiknek hozzáférése van a fájlhoz/mappához)",
    "Path" : "Útvonal",
    "_%n byte_::_%n bytes_" : ["%n bájt","%n bájt"],
    "Favorited" : "Kedvenc",
    "Favorite" : "Kedvenc",
    "New folder" : "Új mappa",
    "Upload file" : "Fájl feltöltés",
    "Not favorited" : "Nincs a kedvencek között",
    "Remove from favorites" : "Eltávolítás a kedvencekből",
    "Add to favorites" : "Hozzáadás a kedvencekhez",
    "An error occurred while trying to update the tags" : "Hiba történt, miközben megpróbálta frissíteni a címkéket",
    "Added to favorites" : "Hozzáadva a kedvencekhez",
    "Removed from favorites" : "Eltávolítva a kedvencekből",
    "You added {file} to your favorites" : "Hozzáadtad a kedvenceidhez: {file}",
    "You removed {file} from your favorites" : "Eltávolítottad a kedvenceidből: {file}",
    "File changes" : "Fájl változások",
    "Created by {user}" : "Létrehozta: {user}",
    "Changed by {user}" : "Módosította: {user}",
    "Deleted by {user}" : "Törölte: {user}",
    "Restored by {user}" : "Visszaállította: {user}",
    "Renamed by {user}" : "Átnevezte: {user}",
    "Moved by {user}" : "Áthelyezte: {user}",
    "\"remote user\"" : "\"távoli felhasználó\"",
    "You created {file}" : "Létrehoztad: {file}",
    "You created an encrypted file in {file}" : "Létrehoztál egy titkosított fájlt ebben: {file}",
    "{user} created {file}" : "{user} létrehozta: {file}",
    "{user} created an encrypted file in {file}" : "{user} létrehozott egy titkosított fájlt ebben: {file}",
    "{file} was created in a public folder" : "{file} létrehozva egy nyilvános mappában",
    "You changed {file}" : "Módosítottad: {file}",
    "You changed an encrypted file in {file}" : "Megváltoztattál egy titkosított fájlt ebben: {file}",
    "{user} changed {file}" : "{user} módosította: {file}",
    "{user} changed an encrypted file in {file}" : "{user} megváltoztatott egy titkosított fájlt ebben: {file}",
    "You deleted {file}" : "Törölted: {file}",
    "You deleted an encrypted file in {file}" : "Töröltél egy titkosított fájlt itt: {file}",
    "{user} deleted {file}" : "{user} törölte: {file}",
    "{user} deleted an encrypted file in {file}" : "{user} törölt egy titkosított fájlt itt: {file}",
    "You restored {file}" : "Visszaállítottad: {file}",
    "{user} restored {file}" : "{user} visszaállította: {file}",
    "You renamed {oldfile} to {newfile}" : "Átnevezted ezt: {oldfile} erre: {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} átnevezte ezt: {oldfile} erre: {newfile}",
    "You moved {oldfile} to {newfile}" : "Áthelyezted ezt: {oldfile} ide: {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} áthelyezte ezt: {oldfile} ide: {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Egy fájl eltávolítva vagy hozzáadva a <strong>kedvenceidhez</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "A fájl vagy mappa <strong>megváltozott</strong> vagy <strong>át lett nevezve</strong>",
    "A new file or folder has been <strong>created</strong>" : "Új fájl vagy mappa <strong>létrehozva</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fájl vagy mappa <strong>törölve</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Szűkítse le az értesítéseket a létrehozásról és a változásokról a <strong>kedvenc fájlok</strong> <em>(Stream only)</em> -ra",
    "A file or folder has been <strong>restored</strong>" : "Egy új fájl vagy mappa <strong>visszaállítva</strong>",
    "Unlimited" : "Korlátlan",
    "Upload (max. %s)" : "Feltöltés (max.: %s)",
    "File handling" : "Fájlkezelés",
    "Maximum upload size" : "Maximális feltölthető fájlméret",
    "max. possible: " : "max. lehetséges: ",
    "Save" : "Mentés",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-mel akár 5 percbe is telhet, míg ez a beállítás érvénybe lép.",
    "Missing permissions to edit from here." : "Innen nem lehet szerkeszteni hiányzó jogosultság miatt.",
    "%s used" : "%s használt",
    "Settings" : "Beállítások",
    "Show hidden files" : "Rejtett fájlok megjelenítése",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Használd ezt a címet a <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">fájlok WebDAV-al való eléréséhez</a>",
    "Cancel upload" : "Feltöltés megszakítása",
    "No files in here" : "Itt nincsenek fájlok",
    "Upload some content or sync with your devices!" : "Tölts fel néhány tartalmat, vagy szinkronizálj az eszközöddel!",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
    "Select all" : "Összes kijelölése",
    "Upload too large" : "A feltöltés túl nagy",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "A feltöltendő fájlok mérete meghaladja a szerveren megengedett maximális méretet.",
    "No favorites yet" : "Még nincsenek kedvencek",
    "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találod meg",
    "Tags" : "Címkék",
    "Deleted files" : "Törölt fájlok",
    "Shared with others" : "Megosztva másokkal",
    "Shared with you" : "Megosztva veled",
    "Shared by link" : "Megosztva hivatkozással",
    "Text file" : "Szövegfájl",
    "New text file.txt" : "Új szöveges fájl.txt",
    "Move" : "Áthelyezés",
    "Target folder" : "Cél mappa",
    "A new file or folder has been <strong>deleted</strong>" : "Egy új fájl vagy mappa <strong>törölve</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Egy új fájl vagy mappa <strong>visszaállítva</strong>",
    "%s of %s used" : "%s / %s használt",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Használja ezt a címet <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">a Fájlok eléréséhez WebDAV-on keresztül</a>."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/hu.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
    "Storage invalid" : "A tároló érvénytelen",
    "Unknown error" : "Ismeretlen hiba",
    "All files" : "Az összes fájl",
    "Recent" : "Legutóbbi",
    "Favorites" : "Kedvencek",
    "File could not be found" : "Fájl nem található",
    "Move or copy" : "Mozgatás vagy másolás",
    "Download" : "Letöltés",
    "Delete" : "Törlés",
    "Home" : "Saját mappa",
    "Close" : "Bezárás",
    "Could not create folder \"{dir}\"" : "{dir} mappa nem hozható létre",
    "Upload cancelled." : "A feltöltést megszakítottuk.",
    "…" : "...",
    "Processing files …" : "Fájlok feldolgozása …",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "A(z) {filename} fájl nem tölthető fel, mert ez vagy egy könyvtár, vagy pedig 0 bájtból áll.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nincs elég szabad hely. A feltöltés mérete {size1}, de csak ennyi hely van: {size2}.",
    "Target folder \"{dir}\" does not exist any more" : "A célmappa már nem létezik: \"{dir}\"",
    "Not enough free space" : "Nincs elég szabad hely",
    "Uploading …" : "Feltöltés...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Ennek az elemnek a feltöltése nem támogatott",
    "Target folder does not exist any more" : "A célmappa már nem létezik",
    "Error when assembling chunks, status code {status}" : "Hiba a darabok összerakásakor, Állapotkód {status}",
    "Actions" : "Műveletek",
    "Rename" : "Átnevezés",
    "Copy" : "Másolás",
    "Choose target folder" : "Célmappa kiválasztása",
    "Disconnect storage" : "Tároló leválasztása",
    "Unshare" : "A megosztás visszavonása",
    "Could not load info for file \"{file}\"" : "Nem sikerült betölteni az információs fájl ehhez: \"{file}\"",
    "Files" : "Fájlok",
    "Details" : "Részletek",
    "Select" : "Kiválaszt",
    "Pending" : "Folyamatban",
    "Unable to determine date" : "Nem lehet meghatározni a dátumot",
    "This operation is forbidden" : "Tiltott művelet",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ez a könyvtár nem elérhető, kérem nézze meg a naplófájlokat vagy keresse a rendszergazdát",
    "Could not move \"{file}\", target exists" : "{file} fájl nem áthelyezhető, mert a cél már létezik",
    "Could not move \"{file}\"" : "{file} fájl nem áthelyezhető",
    "Could not copy \"{file}\", target exists" : "Nem sikerült \"{file}\" másolása, a cél már létezik",
    "Could not copy \"{file}\"" : "\"{file}\" másolása sikertelen",
    "Copied {origin} inside {destination}" : "{origin} átmásolva ide: {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} és {nbfiles} egyéb fájl átmásolva ide: {destination}",
    "{newName} already exists" : "{newName} már létezik",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nem átnevezhető erre: {fileName}, mert már nem létezik",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "{targetName} már használatban van ebben a mappában: {dir}. Kérjük, válassz másik nevet.",
    "Could not rename \"{fileName}\"" : "{fileName} fájl nem átnevezhető",
    "Could not create file \"{file}\"" : "{file} fájl nem létrehozható",
    "Could not create file \"{file}\" because it already exists" : "{file} fájl nem létrehozható, mert már létezik",
    "Could not create folder \"{dir}\" because it already exists" : "{dir} mappa nem hozható létre, mert már létezik",
    "Error deleting file \"{fileName}\"." : "Hiba történt {fileName} fájl törlése közben.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ehhez nincsenek keresési eredmények más mappákban: {tag}{filter}{endtag}",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "_%n folder_::_%n folders_" : ["%n mappa","%n mappa"],
    "_%n file_::_%n files_" : ["%n fájl","%n fájl"],
    "{dirs} and {files}" : "{dirs} és {files}",
    "_including %n hidden_::_including %n hidden_" : ["beleértve %n rejtett","beleértve %n rejtett"],
    "You don’t have permission to upload or create files here" : "Nincs jogosultságod fájlok feltöltéséhez vagy létrehozásához ide",
    "_Uploading %n file_::_Uploading %n files_" : ["%n fájl feltöltése","%n fájl feltöltése"],
    "New" : "Új",
    "{used} of {quota} used" : "{used} / {quota} felhasználva",
    "{used} used" : "{used} felhasználva",
    "\"{name}\" is an invalid file name." : "\"{name}\" érvénytelen, mint fájlnév.",
    "File name cannot be empty." : "A fájlnév nem lehet semmi.",
    "\"/\" is not allowed inside a file name." : "„/” nem szerepelhet fájlnévben.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nem engedélyetett fájltípus",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "A {owner} felhasználó tárolója betelt, a fájlok nem frissíthetők és szinkronizálhatók többet!",
    "Your storage is full, files can not be updated or synced anymore!" : "A tároló tele van, a fájlok nem frissíthetőek vagy szinkronizálhatóak a jövőben.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "A {owner} felhasználó tárolója majdnem betelt ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "A tároló majdnem tele van ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["egyezés '{filter}'","egyezés '{filter}'"],
    "View in folder" : "Megtekintés mappában",
    "Copied!" : "Másolva!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Közvetlen hivatkozás másolása (csak azoknál a felhasználóknál működik akiknek hozzáférése van a fájlhoz/mappához)",
    "Path" : "Útvonal",
    "_%n byte_::_%n bytes_" : ["%n bájt","%n bájt"],
    "Favorited" : "Kedvenc",
    "Favorite" : "Kedvenc",
    "New folder" : "Új mappa",
    "Upload file" : "Fájl feltöltés",
    "Not favorited" : "Nincs a kedvencek között",
    "Remove from favorites" : "Eltávolítás a kedvencekből",
    "Add to favorites" : "Hozzáadás a kedvencekhez",
    "An error occurred while trying to update the tags" : "Hiba történt, miközben megpróbálta frissíteni a címkéket",
    "Added to favorites" : "Hozzáadva a kedvencekhez",
    "Removed from favorites" : "Eltávolítva a kedvencekből",
    "You added {file} to your favorites" : "Hozzáadtad a kedvenceidhez: {file}",
    "You removed {file} from your favorites" : "Eltávolítottad a kedvenceidből: {file}",
    "File changes" : "Fájl változások",
    "Created by {user}" : "Létrehozta: {user}",
    "Changed by {user}" : "Módosította: {user}",
    "Deleted by {user}" : "Törölte: {user}",
    "Restored by {user}" : "Visszaállította: {user}",
    "Renamed by {user}" : "Átnevezte: {user}",
    "Moved by {user}" : "Áthelyezte: {user}",
    "\"remote user\"" : "\"távoli felhasználó\"",
    "You created {file}" : "Létrehoztad: {file}",
    "You created an encrypted file in {file}" : "Létrehoztál egy titkosított fájlt ebben: {file}",
    "{user} created {file}" : "{user} létrehozta: {file}",
    "{user} created an encrypted file in {file}" : "{user} létrehozott egy titkosított fájlt ebben: {file}",
    "{file} was created in a public folder" : "{file} létrehozva egy nyilvános mappában",
    "You changed {file}" : "Módosítottad: {file}",
    "You changed an encrypted file in {file}" : "Megváltoztattál egy titkosított fájlt ebben: {file}",
    "{user} changed {file}" : "{user} módosította: {file}",
    "{user} changed an encrypted file in {file}" : "{user} megváltoztatott egy titkosított fájlt ebben: {file}",
    "You deleted {file}" : "Törölted: {file}",
    "You deleted an encrypted file in {file}" : "Töröltél egy titkosított fájlt itt: {file}",
    "{user} deleted {file}" : "{user} törölte: {file}",
    "{user} deleted an encrypted file in {file}" : "{user} törölt egy titkosított fájlt itt: {file}",
    "You restored {file}" : "Visszaállítottad: {file}",
    "{user} restored {file}" : "{user} visszaállította: {file}",
    "You renamed {oldfile} to {newfile}" : "Átnevezted ezt: {oldfile} erre: {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} átnevezte ezt: {oldfile} erre: {newfile}",
    "You moved {oldfile} to {newfile}" : "Áthelyezted ezt: {oldfile} ide: {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} áthelyezte ezt: {oldfile} ide: {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Egy fájl eltávolítva vagy hozzáadva a <strong>kedvenceidhez</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "A fájl vagy mappa <strong>megváltozott</strong> vagy <strong>át lett nevezve</strong>",
    "A new file or folder has been <strong>created</strong>" : "Új fájl vagy mappa <strong>létrehozva</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fájl vagy mappa <strong>törölve</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Szűkítse le az értesítéseket a létrehozásról és a változásokról a <strong>kedvenc fájlok</strong> <em>(Stream only)</em> -ra",
    "A file or folder has been <strong>restored</strong>" : "Egy új fájl vagy mappa <strong>visszaállítva</strong>",
    "Unlimited" : "Korlátlan",
    "Upload (max. %s)" : "Feltöltés (max.: %s)",
    "File Management" : "Fájlkezelés",
    "File handling" : "Fájlkezelés",
    "Maximum upload size" : "Maximális feltölthető fájlméret",
    "max. possible: " : "max. lehetséges: ",
    "Save" : "Mentés",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-mel akár 5 percbe is telhet, míg ez a beállítás érvénybe lép.",
    "Missing permissions to edit from here." : "Innen nem lehet szerkeszteni hiányzó jogosultság miatt.",
    "%1$s of %2$s used" : "%1$s a %2$s-ból használva",
    "%s used" : "%s használt",
    "Settings" : "Beállítások",
    "Show hidden files" : "Rejtett fájlok megjelenítése",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Használd ezt a címet a <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">fájlok WebDAV-al való eléréséhez</a>",
    "Toggle grid view" : "Rácsnézet váltás",
    "Cancel upload" : "Feltöltés megszakítása",
    "No files in here" : "Itt nincsenek fájlok",
    "Upload some content or sync with your devices!" : "Tölts fel néhány tartalmat, vagy szinkronizálj az eszközöddel!",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
    "Select all" : "Összes kijelölése",
    "Upload too large" : "A feltöltés túl nagy",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "A feltöltendő fájlok mérete meghaladja a szerveren megengedett maximális méretet.",
    "No favorites yet" : "Még nincsenek kedvencek",
    "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találod meg",
    "Tags" : "Címkék",
    "Deleted files" : "Törölt fájlok",
    "Shares" : "Megosztások",
    "Shared with others" : "Megosztva másokkal",
    "Shared with you" : "Megosztva veled",
    "Shared by link" : "Megosztva hivatkozással",
    "Deleted shares" : "Törölt megosztások",
    "Text file" : "Szövegfájl",
    "New text file.txt" : "Új szöveges fájl.txt",
    "Move" : "Áthelyezés",
    "Target folder" : "Célmappa",
    "A new file or folder has been <strong>deleted</strong>" : "Egy új fájl vagy mappa <strong>törölve</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Egy új fájl vagy mappa <strong>visszaállítva</strong>",
    "%s of %s used" : "%s / %s használt",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Használja ezt a címet <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">a Fájlok eléréséhez WebDAV-on keresztül</a>."
},
"nplurals=2; plural=(n != 1);");
